import 'package:flutter/material.dart';
import 'package:flutter_jiopay_pg/flutter_jiopay_pg.dart';

import 'package:flutter/services.dart';

import 'dart:async';




import 'package:fluttertoast/fluttertoast.dart';



class HomeScreen extends StatefulWidget {
  HomeScreenState createState() => HomeScreenState();
}

class HomeScreenState extends State<HomeScreen>{

  final appToken = TextEditingController();
  final userIdToken = TextEditingController();
  final intentId = TextEditingController();
  final headingTextColor = TextEditingController();
  final bodyBgColor = TextEditingController();
  final bodyTextColor = TextEditingController();
  final brandColor = TextEditingController();


  openCheckout(BuildContext context){
    var options={
      'appaccesstoken': appToken.text,
      'appidtoken': userIdToken.text,
      'intentid': intentId.text,
      'theme': {
        'brandColor': headingTextColor.text,
        'bodyBgColor': bodyBgColor.text,
        'bodyTextColor': bodyTextColor.text,
        'headingText': brandColor.text,
      },
    };

    JiopayPg jiopayFlutterPlugin= JiopayPg();
    jiopayFlutterPlugin.on(JiopayPg.EVENT_PAYMENT_SUCCESS, _handlePaymentSuccess);
    jiopayFlutterPlugin.on(JiopayPg.EVENT_PAYMENT_ERROR, _handlePaymentError);
    jiopayFlutterPlugin.open(options);

  }

  void _handlePaymentSuccess(PaymentSuccessResponse response) {
    Fluttertoast.showToast(
        msg: "SUCCESS: " + response.tnxId!, toastLength: Toast.LENGTH_SHORT);
  }

  void _handlePaymentError(PaymentFailureResponse response) {
    debugPrint('_handlePaymentError: $response');
    Fluttertoast.showToast(
        msg: "ERROR: " + response.code.toString() + " - " + response.message!+' - '+response.intentId!,
        toastLength: Toast.LENGTH_SHORT);
  }

  @override
  Widget build(BuildContext context) {

    return Scaffold(
        resizeToAvoidBottomInset: true,
        body: SingleChildScrollView(
          child: Column(
            children: <Widget>[

      Stack(
          alignment: const Alignment(1.0, 1.0),
          children:  <Widget>[
            Container(
                width: Size.infinite.width,
                padding: EdgeInsets.all(10.0),
                child: TextField(
                  controller: appToken,
                  decoration:const InputDecoration(hintText: 'Enter App Token'),
                )
            ),
            ElevatedButton(
              onPressed:() async {
                ClipboardData? data = await Clipboard.getData('text/plain');
                appToken.text= data?.text??"";
              },
              style: ElevatedButton.styleFrom(backgroundColor:Color(0xff1793ff) ,padding: const EdgeInsets.fromLTRB(10, 10, 10, 10) ),
              child: const Text('Paste'),
            ),
          ]
      ),

              Stack(
                  alignment: const Alignment(1.0, 1.0),
                  children:  <Widget>[
                    Container(
                        width: Size.infinite.width,
                        padding:const EdgeInsets.all(10.0),
                        child: TextField(
                          controller: userIdToken,

                          decoration: const InputDecoration(hintText: 'User Id Token'),
                        )
                    ),
                    ElevatedButton(
                      onPressed:() async {
                        ClipboardData? data = await Clipboard.getData('text/plain');
                        userIdToken.text= data?.text??"";
                      },
                      style: ElevatedButton.styleFrom(backgroundColor:Color(0xff1793ff) ,padding: const EdgeInsets.fromLTRB(10, 10, 10, 10) ),
                      child: const Text('Paste'),
                    ),
                  ]
              ),

             Stack(
                 alignment: const Alignment(1.0, 1.0),
                 children:  <Widget>[
                   Container(
                       width: Size.infinite.width,
                       padding:const EdgeInsets.all(10.0),
                       child: TextField(
                         controller: intentId,

                         decoration:const InputDecoration(hintText: 'Intent ID Token'),
                       )
                   ),
                   ElevatedButton(
                     onPressed:() async {
                       ClipboardData? data = await Clipboard.getData('text/plain');
                       intentId.text= data?.text??"";
                     },
                     style: ElevatedButton.styleFrom(backgroundColor:Color(0xff1793ff) ,padding: const EdgeInsets.fromLTRB(10, 10, 10, 10) ),
                     child: const Text('Paste'),
                   ),
                 ]
             ),



              Container(
                  width: Size.infinite.width,
                  padding:const EdgeInsets.all(10.0),
                  child: TextField(
                    controller: headingTextColor,

                    decoration:const InputDecoration(hintText: 'Heading Text Color'),
                  )
              ),
              Container(
                  width: Size.infinite.width,
                  padding:const EdgeInsets.all(10.0),
                  child: TextField(
                    controller: bodyBgColor,

                    decoration:const InputDecoration(hintText: 'Body Background'),
                  )
              ),
              Container(
                  width: Size.infinite.width,
                  padding:const EdgeInsets.all(10.0),
                  child: TextField(
                    controller: bodyTextColor,

                    decoration:const InputDecoration(hintText: 'Body Text Color'),
                  )
              ),
              Container(
                  width: Size.infinite.width,
                  padding:const EdgeInsets.all(10.0),
                  child: TextField(
                    controller: brandColor,
                    decoration: const InputDecoration(hintText: 'Brand Color'),
                  )
              ),
              ElevatedButton(
                onPressed:()=> openCheckout(context),
                style: ElevatedButton.styleFrom(backgroundColor:Color(0xff1793ff) ,padding: const EdgeInsets.fromLTRB(10, 10, 10, 10) ),
                child: const Text('Submit'),
              ),

            ],
          ),
        ));
  }
}