
import 'dart:async';

import 'package:eventify/eventify.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/services.dart';

class JiopayPg {
  //status code
  static const _CODE_PAYMENT_SUCCESS = 0;
  static const _CODE_PAYMENT_ERROR = 1;

  // Event names
  static const EVENT_PAYMENT_SUCCESS = 'payment.success';
  static const EVENT_PAYMENT_ERROR = 'payment.error';
  static const UNKNOWN_ERROR = "100";

  late EventEmitter _eventEmitter;
  static const MethodChannel _channel = MethodChannel('flutter_jiopay_pg');

  JiopayPg() {
    _eventEmitter = new EventEmitter();
  }

  void open(Map<String, dynamic> options)  async{
    Map<String, dynamic> validationResult = _validateOptions(options);
    if (!validationResult['success']) {
      _handleResult({
        'type': _CODE_PAYMENT_ERROR,
        'data': {
          'code': "ERROR",
          'message': validationResult['message']
        }
      });
      return;
    }
    var response =  await _channel.invokeMethod('open', options);
    _handleResult(response);
  }


  /// Validate payment options
  static Map<String, dynamic> _validateOptions(Map<String, dynamic> options) {
    String appaccesstoken = options['appaccesstoken'];
    String appidtoken=options['appidtoken'];
    String intentid=options['intentid'];
    String message="";
    if(appaccesstoken==null ||appaccesstoken.isEmpty){
      message='appaccesstoken is required. Please check if appaccesstoken is present in options.';
    }
    if(appidtoken==null ||appidtoken.isEmpty){
      message='appidtoken is required. Please check if appidtoken is present in options.';
    }
    if(intentid==null ||intentid.isEmpty){
      message='intentid is required. Please check if intentid is present in options.';
    }

    return {'success': message.isEmpty? true:false,
      'message':message
    };
  }

  void on(String event, Function handler) {
    EventCallback cb = (event, cont) {
      handler(event.eventData);
    };
    _eventEmitter.on(event, null, cb);
    _resync();
  }
  /// Clears all event listeners
  void clear() {
    _eventEmitter.clear();
  }

  /// Retrieves lost responses from platform
  void _resync() async {
    var response = await _channel.invokeMethod('resync');
    if (response != null) {
      _handleResult(response);
    }
  }

  void _handleResult(Map<dynamic, dynamic> response) {
    String eventName;
    Map<dynamic, dynamic>? data = response["data"];
    dynamic payload;
    switch (response['type']) {
      case _CODE_PAYMENT_SUCCESS:
        eventName = EVENT_PAYMENT_SUCCESS;
        payload = PaymentSuccessResponse.fromMap(data!);
        break;

      case _CODE_PAYMENT_ERROR:
        eventName = EVENT_PAYMENT_ERROR;
        payload = PaymentFailureResponse.fromMap(data!);
        break;

      default:
        eventName = 'error';
        payload = PaymentFailureResponse(UNKNOWN_ERROR, 'An unknown error occurred.','');
    }
    debugPrint('eventName: $eventName');
    debugPrint('payload[JJ]: ${payload}');
    _eventEmitter.emit(eventName, null, payload);
  }
}

class PaymentSuccessResponse {
  String? tnxId;
  String? intentId;

  PaymentSuccessResponse(this.tnxId, this.intentId);

  static PaymentSuccessResponse fromMap(Map<dynamic, dynamic> map) {
    String? tnxId = map["tnxId"];
    String? intentId = map["intentId"];
    return  PaymentSuccessResponse(tnxId, intentId);
  }
}


class PaymentFailureResponse {
  String? code;
  String? message;
  String? intentId;
  PaymentFailureResponse(this.code, this.message,this.intentId);
  static PaymentFailureResponse fromMap(Map<dynamic, dynamic> map) {
    var code = map["code"] as String?;
    var message = map["message"] as String?;
    var intentId = map["intentId"] as String?;
    return PaymentFailureResponse(code, message,intentId);
  }
}

